@@ -1,4 +1,4 @@
-__version__ = "0.6.1"
+__version__ = "0.6.2"
 
 from .prover import ResolutionProver, Proof, ProofStep
 
@@ -17,7 +17,12 @@ from .types import (
     Clause,
 )
 
-from .similarity import cosine_similarity, symbol_compare, max_similarity
+from .similarity import (
+    cosine_similarity,
+    symbol_compare,
+    max_similarity,
+    SimilarityFunc,
+)
 
 __all__ = (
     "ResolutionProver",
@@ -36,6 +41,7 @@ __all__ = (
     "cosine_similarity",
     "symbol_compare",
     "max_similarity",
+    "SimilarityFunc",
     "Proof",
     "ProofStep",
 )
